/****************************************************************************
** Meta object code from reading C++ file 'quickviewsharedengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libplasma-6.6.5/src/plasmaquick/quickviewsharedengine.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickviewsharedengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaQuick::QuickViewSharedEngine::qt_create_metaobjectdata<qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaQuick::QuickViewSharedEngine",
        "statusChanged",
        "",
        "QQmlComponent::Status",
        "status",
        "resizeModeChanged",
        "QuickViewSharedEngine::ResizeMode",
        "resizeMode",
        "sourceChanged",
        "QUrl",
        "source",
        "setSource",
        "url",
        "executionFinished",
        "syncWidth",
        "syncHeight",
        "ResizeMode",
        "SizeViewToRootObject",
        "SizeRootObjectToView"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(QQmlComponent::Status)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'resizeModeChanged'
        QtMocHelpers::SignalData<void(QuickViewSharedEngine::ResizeMode)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'executionFinished'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'syncWidth'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'syncHeight'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resizeMode'
        QtMocHelpers::PropertyData<enum ResizeMode>(7, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'status'
        QtMocHelpers::PropertyData<QQmlComponent::Status>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ResizeMode'
        QtMocHelpers::EnumData<enum ResizeMode>(16, 16, QMC::EnumFlags{}).add({
            {   17, ResizeMode::SizeViewToRootObject },
            {   18, ResizeMode::SizeRootObjectToView },
        }),
    };
    return QtMocHelpers::metaObjectData<QuickViewSharedEngine, qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11PlasmaQuick21QuickViewSharedEngineE[] = {
    QMetaObject::SuperData::link<QQmlComponent::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PlasmaQuick::QuickViewSharedEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11PlasmaQuick21QuickViewSharedEngineE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>.metaTypes,
    nullptr
} };

void PlasmaQuick::QuickViewSharedEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickViewSharedEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent::Status>>(_a[1]))); break;
        case 1: _t->resizeModeChanged((*reinterpret_cast<std::add_pointer_t<QuickViewSharedEngine::ResizeMode>>(_a[1]))); break;
        case 2: _t->sourceChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->d->executionFinished(); break;
        case 5: _t->d->syncWidth(); break;
        case 6: _t->d->syncHeight(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QuickViewSharedEngine::*)(QQmlComponent::Status )>(_a, &QuickViewSharedEngine::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickViewSharedEngine::*)(QuickViewSharedEngine::ResizeMode )>(_a, &QuickViewSharedEngine::resizeModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickViewSharedEngine::*)(const QUrl & )>(_a, &QuickViewSharedEngine::sourceChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ResizeMode*>(_v) = _t->resizeMode(); break;
        case 1: *reinterpret_cast<QQmlComponent::Status*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResizeMode(*reinterpret_cast<enum ResizeMode*>(_v)); break;
        case 2: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaQuick::QuickViewSharedEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaQuick::QuickViewSharedEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlasmaQuick21QuickViewSharedEngineE_t>.strings))
        return static_cast<void*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int PlasmaQuick::QuickViewSharedEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PlasmaQuick::QuickViewSharedEngine::statusChanged(QQmlComponent::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlasmaQuick::QuickViewSharedEngine::resizeModeChanged(QuickViewSharedEngine::ResizeMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlasmaQuick::QuickViewSharedEngine::sourceChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
